#!/usr/bin/env python
# -*- encoding: utf8 -*-

from jing.data_center import DataCenter
from jing.reference import Reference

import pandas as pd

import warnings
warnings.filterwarnings("ignore")

pd.set_option('display.max_columns', None)

class Y:
    def __init__(self, code, _date="", _market="us") -> None:
        self.market = _market
        self.date = _date
        self.code = code

        self.data_center = DataCenter(self.market)
        self.df = self.data_center.one(self.code, self.date) 
        self.ref = Reference(self.df)

if __name__=="__main__":
    y = Y("IONQ", _date="2024-09-27")
    ref = y.ref
    print(ref.date(0), ref.ma20(0), ref.ma50(0), ref.ma200(0), ref.vma50(0), ref.macd(0), ref.diff(0), ref.dea(0))



#!/usr/bin/env python
# -*- coding: UTF-8 -*-

from jing.data_center import DataCenter
from jing.tech import Tech

class Reference:
    def __init__(self, _df) -> None:
        self.df = Tech(_df).calc()
        self.df = self.df.sort_index(ascending=False).dropna()

    def close(self, _i):
        try:
            v = self.df['Close'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def vol(self, _i):
        try:
            v = self.df['Volume'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def len(self):
        return len(self.df)

    def date(self, _i):
        try:
            v = self.df.index[_i]
            return v
        except Exception as e:
            print(e)
            return e

    def ma20(self, _i):
        try:
            v = self.df['ma20'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def ma50(self, _i):
        try:
            v = self.df['ma50'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def ma200(self, _i):
        try:
            v = self.df['ma200'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def Ma200(self):
        return self.df['ma200'].dropna()

    def Ma50(self):
        return self.df['ma50'].dropna()

    def Close(self):
        return self.df['Close'].dropna()

    def vma50(self, _i):
        try:
            v = self.df['vma50'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def macd(self, _i):
        try:
            v = self.df['macd'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def diff(self, _i):
        try:
            v = self.df['diff'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

    def dea(self, _i):
        try:
            v = self.df['dea'].iloc[_i]
            return float(v)
        except Exception as e:
            print(e)
            return e

if __name__ == "__main__":
    dc = DataCenter()
    df = dc.one("IONQ", _date='2024-09-27')
    ref = Reference(df)
    price = ref.close(0)
    vol = ref.vol(0)
    print(price, vol, ref.date(0), ref.ma20(0), ref.ma50(0), ref.ma200(0), ref.vma50(0), ref.macd(0), ref.diff(0), ref.dea(0))



#!/usr/bin/python
# -*- encoding: utf8 -*-

import logging
import logging.handlers
import os
import sys

sai_dft_log = "sai.log"
sai_dft_fmt = "%(asctime)s - %(filename)s:%(lineno)s - %(message)s"
sai_dft_tm  = "%m-%d %H:%M:%S"
sai_dft_path= os.environ['LOG'] + '/'
#fm=logging.Formatter("%(asctime)s  %(levelname)s - %(message)s", "%Y-%m-%d %H:%M:%S")

g_logger = logging.getLogger(sai_dft_path+"sai.log")

def getLogger():
    return g_logger

def initLogger(name=None):
    logger = logging.getLogger(name)
    logger.setLevel(logging.DEBUG)

    if not name:
        name = sai_dft_log

    # new
    fm=logging.Formatter(sai_dft_fmt, sai_dft_tm)
    rh=logging.handlers.TimedRotatingFileHandler(sai_dft_path+name, 'D')
    rh.setFormatter(fm)
    logger.addHandler(rh)

    logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)

    global g_logger
    g_logger = logger
    return logger

def loggerStdout():
    logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)


if __name__ == "__main__":
    initLogger("x.log")
    logger = getLogger()

    # loggerStdout()
    logger.debug("hello debug 2")
    logger.info("hello info 2")



#!/usr/bin/env python
# -*- encoding: utf8 -*-

import pandas as pd

import warnings
warnings.filterwarnings("ignore")

from jing.data_center import DataCenter
from jing.reference import Reference
from jing.rule_set import RuleSet

from jing.rule import RuleSimple
from jing.rule import RulePriceBreakout

pd.set_option('display.max_columns', None)

class X:
    def __init__(self, _market="cn", _date="", _code="") -> None:
        self.market = _market
        self.date = _date
        self.data_center = DataCenter()
        self.rule_map = {}
        self.result = []

        if len(_code) > 0:
            self.list = pd.DataFrame({'code':[_code]})
        else:
            self.list = self.data_center.list(market=_market)

    def list(self):
        return self.list

    def add_rule(self, _rule_class):
        self.rule_map = {_rule_class.__class__.__name__:_rule_class}

    def run(self, _lookBack=0):
        for i, row in self.list.iterrows():
            code = row['code']
            print(f"--{code}")
            self.run_one(code, _lookBack)

    def run_one(self, _code, _lookBack=0):
        self.one = self.data_center.one(_code, self.date)
        if len(self.one) < 400:
            print(f"{_code} -- bye")
            return

        self.ref = Reference(self.one)

        rs = RuleSet(_code, self.ref)
        for rule_name, rule_class in self.rule_map.items():
            rs.add_rule(rule_class)
        rs.run()
        self.result.append(rs.get_result())

if __name__=="__main__":
    # x = X("us", "2023-10-30")

    # ma50 - ma200
    # x = X("us", "2023-10-30", "NFLX")
    # x = X("us", "2023-11-01", "AMD")
    # x.run()

    # breakout +
    # x = X("us", "2024-01-19", "SMCI") # breakout

    # x = X("us", "2023-05-24", "ANF", "volumeBreakout")
    # x = X("us", "2024-01-19", "SMCI", "volumeBreakout")
    # x.run()
    #x = X("us", "2024-02-16")

    #x = X("us", "2024-05-25")
    #x.run(5)

    x = X("us", "2024-09-27", "IONQ")
    x.add_rule(RuleSimple)
    x.run()

    # x = X("us", "2024-09-27")
    # x.add_rule(RuleSimple)
    # x.run()

    x = X("us", "2024-01-19", "SMCI")
    x.add_rule(RulePriceBreakout)
    x.run()
    print(x.result)

